SELECT 1/pyro-sync - Criterion.rs

## SELECT 1/pyro-sync

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0001193 | 0.0001234 | 0.0001184
Mean | 4.3444 ms | 4.4145 ms | 4.4917 ms
Std. Dev. | 292.74 µs | 377.64 µs | 451.90 µs
Median | 4.2643 ms | 4.3610 ms | 4.4443 ms
MAD | 259.87 µs | 325.60 µs | 395.52 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.